$OpenBSD: patch-src_ngircd_ngircd_c,v 1.2 2013/01/19 20:40:57 fgsch Exp $
--- src/ngircd/ngircd.c.orig	Tue Jan  1 18:22:33 2013
+++ src/ngircd/ngircd.c	Fri Jan 18 01:31:56 2013
@@ -570,7 +570,7 @@ Setup_FDStreams(int fd)
 #if !defined(SINGLE_USER_OS)
 
 /**
  * Get user and group ID of unprivileged "nobody" user.
  *
  * @param uid	User ID
  * @param gid	Group ID
@@ -594,7 +594,7 @@ NGIRCd_getNobodyID(uid_t *uid, gid_t *gid )
 	}
 #endif
 
-	pwd = getpwnam("nobody");
+	pwd = getpwnam("_ngircd");
 	if (!pwd)
 		return false;
 
@@ -701,11 +701,11 @@ NGIRCd_Init(bool NGIRCd_NoDaemon)
 	if (Conf_UID == 0) {
 		pwd = getpwuid(0);
 		Log(LOG_INFO,
-		    "ServerUID must not be %s(0), using \"nobody\" instead.",
+		    "ServerUID must not be %s(0), using \"_ngircd\" instead.",
 		    pwd ? pwd->pw_name : "?");
 		if (!NGIRCd_getNobodyID(&Conf_UID, &Conf_GID)) {
 			Log(LOG_WARNING,
-			    "Could not get user/group ID of user \"nobody\": %s",
+			    "Could not get user/group ID of user \"_ngircd\": %s",
 			    errno ? strerror(errno) : "not found" );
 			goto out;
 		}
@@ -570,7 +570,7 @@ Setup_FDStreams(int fd)
 
 /**
- * Get user and group ID of unprivileged "nobody" user.
+ * Get user and group ID of unprivileged "_ngircd" user.
  *
  * @param uid	User ID
